==> anatools-3.6.0-py3-none-any.whl: anatools/anaclient/api/analytics.py <==
"""
Analytics API calls.
"""

def getAnalytics(self, analyticsId, workspaceId):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "getAnalytics",
            "variables": {
                "workspaceId": workspaceId,
                "analyticsId": analyticsId
            },
            "query": """query 
                getAnalytics($workspaceId: String!, $analyticsId: String!) {
                    getAnalytics(workspaceId: $workspaceId, analyticsId: $analyticsId){
                        analyticsId
                        workspaceId
                        datasetId
                        status
                        result
                        member
                        type
                        range
                        returnImages
                    }
                }"""})
    return self.errorhandler(response, "getAnalytics")


def getAnalyticsTypes(self):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "getAnalyticsTypes",
            "variables": {},
            "query": """query 
                getAnalyticsTypes{
                    getAnalyticsTypes
                }"""})
    return self.errorhandler(response, "getAnalyticsTypes")


def createAnalytics(self, workspaceId, datasetId, rangeInput, typeInput, returnImages):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "createAnalytics",
            "variables": {
                "workspaceId": workspaceId,
                "datasetId": datasetId,
                "range": rangeInput,
                "type": typeInput,
                "returnImages": returnImages
            },
            "query": """mutation 
                createAnalytics($workspaceId: String!, $datasetId: String!, $range: [Int], $type: String!, $returnImages: Boolean) {
                    createAnalytics(workspaceId: $workspaceId, datasetId: $datasetId, range: $range, type: $type, returnImages: $returnImages)
                }"""})
    return self.errorhandler(response, "createAnalytics")


def deleteAnalytics(self, workspaceId, analyticsId):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "deleteAnalytics",
            "variables": {
                "workspaceId": workspaceId,
                "analyticsId": analyticsId
            },
            "query": """mutation 
                deleteAnalytics($workspaceId: String!, $datasetId: String! $analyticsId: String!) {
                    deleteAnalytics(workspaceId: $workspaceId, datasetId: $datasetId, analyticsId: $analyticsId)
                }"""})
    return self.errorhandler(response, "deleteAnalytics")

==> anatools-4.1.4-py3-none-any.whl: anatools/anaclient/api/analytics.py <==
"""
Analytics API calls.
"""

def getAnalytics(self, analyticsId, workspaceId, limit=100, cursor=None, filters=None):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "getAnalytics",
            "variables": {
                "workspaceId": workspaceId,
                "analyticsId": analyticsId,
                "limit": limit,
                "cursor": cursor,
                "filters": filters
            },
            "query": """query 
                getAnalytics($workspaceId: String!, $analyticsId: String, $limit: Int, $cursor: String, $filters: AnalyticsFilter) {
                    getAnalytics(workspaceId: $workspaceId, analyticsId: $analyticsId, limit: $limit, cursor: $cursor, filters: $filters){
                        analyticsId
                        workspaceId
                        datasetId
                        status
                        result
                        member
                        type
                        range
                        returnImages
                    }
                }"""})
    return self.errorhandler(response, "getAnalytics")


def getAnalyticsTypes(self):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "getAnalyticsTypes",
            "variables": {},
            "query": """query 
                getAnalyticsTypes{
                    getAnalyticsTypes
                }"""})
    return self.errorhandler(response, "getAnalyticsTypes")


def createAnalytics(self, workspaceId, datasetId, rangeInput, typeInput, returnImages):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "createAnalytics",
            "variables": {
                "workspaceId": workspaceId,
                "datasetId": datasetId,
                "range": rangeInput,
                "type": typeInput,
                "returnImages": returnImages
            },
            "query": """mutation 
                createAnalytics($workspaceId: String!, $datasetId: String!, $range: [Int], $type: String!, $returnImages: Boolean) {
                    createAnalytics(workspaceId: $workspaceId, datasetId: $datasetId, range: $range, type: $type, returnImages: $returnImages)
                }"""})
    return self.errorhandler(response, "createAnalytics")


def deleteAnalytics(self, workspaceId, analyticsId):
    response = self.session.post(
        url = self.url, 
        headers = self.headers, 
        json = {
            "operationName": "deleteAnalytics",
            "variables": {
                "workspaceId": workspaceId,
                "analyticsId": analyticsId
            },
            "query": """mutation 
                deleteAnalytics($workspaceId: String!, $datasetId: String! $analyticsId: String!) {
                    deleteAnalytics(workspaceId: $workspaceId, datasetId: $datasetId, analyticsId: $analyticsId)
                }"""})
    return self.errorhandler(response, "deleteAnalytics")
